<?php

/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package Post Layouts Pro for Gutenberg
 */
// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Enqueue assets for backend editor
 *
 * @since   1.0.0
 * @package Post Layouts Pro for Gutenberg
 */
function post_layouts_pro_block_editor_assets() {

    // Load the compiled blocks into the editor
    wp_enqueue_script('plp-block-js', plugins_url('/dist/blocks.build.js', dirname(__FILE__)), array('wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-api'), filemtime(plugin_dir_path(__FILE__) . 'blocks.build.js'));

    // Load the compiled styles into the editor
    wp_enqueue_style('plp-block-editor-css', plugins_url('dist/blocks.editor.build.css', dirname(__FILE__)), array('wp-edit-blocks'), filemtime(plugin_dir_path(__FILE__) . 'blocks.editor.build.css'));

    if (function_exists('wp_set_script_translations')) {
        wp_add_inline_script(
                'post-layouts-pro', sprintf(
                        'var post_layouts_pro = { localeData: %s };', json_encode(wp_set_script_translations('post-layouts-pro', PLP_DOMAIN))
                ), 'before'
        );
    }
}

add_action('enqueue_block_editor_assets', 'post_layouts_pro_block_editor_assets');

/**
 * Enqueue assets for frontend and backend
 *
 * @since   1.0.0
 * @package Post Layouts Pro for Gutenberg
 */
function post_layouts_pro_block_assets() {

    $postfix = ( SCRIPT_DEBUG == true ) ? '' : '.min';

    // Load the compiled styles
    wp_enqueue_style('plp-block-style-css', plugins_url('dist/blocks.style.build.css', dirname(__FILE__)), array()
    );

    // Load the FontAwesome icon library
    wp_enqueue_style('plp-block-fontawesome', plugins_url('dist/assets/fontawesome/css/all.css', dirname(__FILE__)), array()
    );

    // Load the coomon stylew for google fonts
    wp_enqueue_style('plp-block-google-fonts', plugins_url('dist/assets/css/common.css', dirname(__FILE__)), array()
    );
}

add_action('enqueue_block_assets', 'post_layouts_pro_block_assets');

// Add custom block category using block_categories_all
add_filter('block_categories_all', function($categories, $editor_context){
    return array_merge(
        $categories,
        array(
            array(
                'slug' => 'post-layouts-pro',
                'title' => __('Post Layouts By Techeshta', 'post-layouts-pro'),
            ),
        )
    );
}, 10, 2);