<?php

/**
 * Server-side rendering for the post template block
 *
 * @since   1.0.0
 * @package Post Layouts Pro for Gutenberg
 */

/**
 * Renders the post block on server.
 */
function post_layouts_pro_block_render_block_core_latest_posts($attributes) {

    $list_items_markup = $post_thumb_id = $selected = '';

    // Build the classes
    if($attributes['layoutopt'] == 'grid'){    
        $selected = $attributes['layoutcount'];
    }

    if($attributes['layoutopt'] == 'list'){    
        $selected = $attributes['layoutcountTwo'];
    }

    $template = $attributes['layoutopt'] . $selected;

    if ($selected && $attributes['layoutopt']) {
        switch ($template) {
            case 'grid1' :
                $list_items_markup = pl_grid_layout1($attributes);
                break;
            case 'grid2' :
                $list_items_markup = pl_grid_layout2($attributes);
                break;
            case 'grid3' :
                $list_items_markup = pl_grid_layout3($attributes);
                break;
            case 'grid4' :
                $list_items_markup = pl_grid_layout4($attributes);
                break;
            case 'grid5' :
                $list_items_markup = pl_grid_layout5($attributes);
                break;
            case 'grid6' :
                $list_items_markup = pl_grid_layout6($attributes);
                break;
            case 'grid7' :
                $list_items_markup = pl_grid_layout7($attributes);
                break;
            case 'grid8' :
                $list_items_markup = pl_grid_layout8($attributes);
                break;
            case 'grid9' :
                $list_items_markup = pl_grid_layout9($attributes);
                break;
            case 'grid10' :
                $list_items_markup = pl_grid_layout10($attributes);
                break;
            case 'list1' :
                $list_items_markup = pl_list_layout1($attributes);
                break;
            case 'list2' :
                $list_items_markup = pl_list_layout2($attributes);
                break;
            case 'list3' :
                $list_items_markup = pl_list_layout3($attributes);
                break;
            case 'list4' :
                $list_items_markup = pl_list_layout4($attributes);
                break;
            case 'list5' :
                $list_items_markup = pl_list_layout5($attributes);
                break;
        }
    }

    $class = "plp-{$attributes['layoutopt']}-template{$selected} align-{$attributes['align']}";

    if (isset($attributes['className'])) {
        $class .= ' ' . $attributes['className'];
    }
    $grid_class = 'plp-blogpost-items';

    if (isset($attributes['layoutopt']) && 'list' === $attributes['layoutopt']) {
        $grid_class .= ' is-list';
    } else {
        $grid_class .= ' is-grid';
    }

    if (isset($attributes['columns']) && 'grid' === $attributes['layoutopt']) {
        $grid_class .= ' columns-' . $attributes['columns'];
    }

    // Output the post markup
    $block_content = sprintf('<div class="%1$s"><div class="%2$s">%3$s</div></div>', esc_attr($class), esc_attr($grid_class), $list_items_markup);

    return $block_content;
}

/*
 *  Get the featured image
 */

function post_layouts_pro_get_featured_image($post_id, $attributes) {
    $fetured_image = '';
    // Get the post thumbnail
    $post_thumb_id = get_post_thumbnail_id($post_id);
    if (isset($attributes['displayPostImage']) && $attributes['displayPostImage'] && $post_thumb_id) {
        if ($attributes['imageCrop'] === 'landscape') {
            $post_thumb_size = 'plp-blogpost-landscape';
        } else {
            $post_thumb_size = 'plp-blogpost-square';
        }

        $fetured_image = sprintf('<div class="plp-image"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), wp_get_attachment_image($post_thumb_id, $post_thumb_size));
    }
    return $fetured_image;
}

/*
 *  Get the category of post
 */

function post_layouts_pro_get_category($post_id, $seprator) {

    $categories_list = get_the_category_list($seprator, "", $post_id);
    $category = "";

    if (!empty($categories_list))
        $category = sprintf('<div class="category-link"> %1$s </div> ', $categories_list);
    return $category;
}

/*
 *  Get the post excerpt
 */

function post_layouts_pro_get_excerpt($post_id, $post, $attributes) {

    $excerpt = apply_filters('the_excerpt', get_post_field('post_excerpt', $post_id, 'display'));

    if (!isset($attributes['wordsExcerpt'])) {
        $wordsExcerpt = 25;
    } else {
        $wordsExcerpt = $attributes['wordsExcerpt'];
    }

    if (empty($excerpt)) {
        $excerpt = apply_filters('the_excerpt', wp_trim_words($post->post_content, $wordsExcerpt));
    }

    if (!$excerpt) {
        $excerpt = null;
    }

    if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
        $excerpt_data = wp_kses_post($excerpt);
    }
    return $excerpt_data;
}

/*
 *  Get the post author
 */

function post_layouts_pro_get_author($post_id, $post) {

    $list_items_markup = sprintf('<a href="%2$s">%1$s</a></span></span>', esc_html(get_the_author_meta('display_name', $post->post_author)), esc_html(get_author_posts_url($post->post_author)));
    return $list_items_markup;
}

/*
 *  Get the post date format
 */

function post_layouts_pro_get_date_format($format) {

    $formate_php = '';
    if ($format == 'DD MMM Y') {
        $formate_php = "d M Y";
    } elseif ($format == 'DD/M/Y') {
        $formate_php = "d/m/Y";
    } elseif ($format == 'MMMM Y') {
        $formate_php = "F Y";
    } elseif ($format == 'MMM-DD-Y') {
        $formate_php = "M-d-Y";
    } elseif ($format == 'DD - MMMM , Y') {
        $formate_php = "d - F ,Y";
    }
    return $formate_php;
}

/*
 *  Get the post tags
 */

function post_layouts_pro_get_tags($post_id, $tag_text) {

    $list_items_markup = '';
    $tags_list = get_the_tag_list("", ", ", "", $post_id);
    if (!empty($tags_list)) {
        if (!empty($tag_text))
            $list_items_markup .= sprintf('<div class="plp-post-tags"><span class="link-label">%1$s </span> %2$s </div> ', $tag_text, $tags_list);
        else
            $list_items_markup .= sprintf('<div class="plp-post-tags"> %1$s </div> ', $tags_list);
    }
    return $list_items_markup;
}

/*
 *  Get the post social share icon
 */

function post_layouts_pro_get_social_share_icons($post_id) {

    $social_share_info = sprintf('<a data-share="facebook" href="https://www.facebook.com/sharer.php?u=%1$s" class="plp-facebook-share social-share-default plp-social-share" target="_blank"><i class="fab fa-facebook-f" aria-hidden="true"></i></a>', get_the_permalink($post_id));
    $social_share_info .= sprintf('<a data-share="twitter" href="https://twitter.com/share?url=%1$s" class="plp-twitter-share social-share-default plp-social-share" target="_blank"><i class="fab fa-twitter" aria-hidden="true"></i></a>', get_the_permalink($post_id));
    $social_share_info .= sprintf('<a data-share="linkedin" href="https://www.linkedin.com/shareArticle?url=%1$s" class="plp-linkedin-share social-share-default plp-social-share" target="_blank"><i class="fab fa-linkedin-in" aria-hidden="true"></i></a>', get_the_permalink($post_id));
    return $social_share_info;
}

/*
 *  Grid template 1
 */

function pl_grid_layout1($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }

        // Get the post title
        $title = get_the_title($post_id);

        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline"> <div class=" metadatabox">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author">');
            $list_items_markup .= __('By ', 'post-layouts-pro');
            $list_items_markup .= sprintf('<span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate">');
            $list_items_markup .= __('On ', 'post-layouts-pro');
            $list_items_markup .= sprintf('%1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }

        // Get post comments
        $number_comment = 0;
        $comments = get_comments_number($post_id);
        sprintf($comments);
        if ($comments > 0) {
            // translators: %s is the number of comments.
            $number_comment = sprintf(_n('%s Comment', '%s Comments', $comments, 'post-layouts-pro'), $comments);
        } else {
            $number_comment = __('No Comments', 'post-layouts-pro');
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf('<div class="post-comments"> %1$s </div>', $number_comment);
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }

        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Close the excerpt content
        $list_items_markup .= sprintf('</div><div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, "");
        }
        $list_items_markup .= sprintf('<div class="plp-social-wrap plp-%1$s">', $attributes['socialopt']);
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
        }
        $list_items_markup .= sprintf('</div></div>');

        // Close the byline content
        $list_items_markup .= sprintf('</div>');

        // Close the text content
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 2
 */

function pl_grid_layout2($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text"><div class="plp-category-link-wraper">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, "& ");
        }
        $list_items_markup .= sprintf('</div>');

        // Get the post title
        $title = get_the_title($post_id);

        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline"> <div class=" metadatabox">');

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate">');
            $list_items_markup .= __('On', 'post-layouts-pro');
            $list_items_markup .= sprintf(' %1$s</div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author">');
            $list_items_markup .= __('By ', 'post-layouts-pro');
            $list_items_markup .= sprintf('<span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</span>');
            $list_items_markup .= sprintf('</div>');
        }

        // Get post comments
        $comments = get_comments_number($post_id);

        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }

        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Close the excerpt content
        $list_items_markup .= sprintf('</div><div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="plp-social-wrap"><i class="fas fa-share-alt"></i><div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div></div>');
        }

        // Close the byline content
        $list_items_markup .= sprintf('</div>');

        // Wrap the text content
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 3
 */

function pl_grid_layout3($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'categories' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));

        $list_items_markup .= sprintf('<div class="plp-blogpost-header-wrap">');

        //social share
        $list_items_markup .= sprintf('<div class="plp-left-wrap">');
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-right-wrap">');

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "> On %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $list_items_markup .= sprintf('</div></div>');

        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');

        // Get the post title
        $title = get_the_title($post_id);

        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        $list_items_markup .= sprintf('<div class="plp-category-link-wraper">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, " | ");
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');

        // Wrap the excerpt content
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Close the excerpt content
        $list_items_markup .= sprintf('</div>');

        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author">By <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 4
 */

function pl_grid_layout4($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));

        $list_items_markup .= sprintf('<div class="plp-image-wrap">');

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, " ");
        }

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));
        $list_items_markup .= sprintf('</div>');

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');

        // Wrap the excerpt content
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"><span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $list_items_markup .= sprintf('</div>');

        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');

        // Get the social share
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 5
 */

function pl_grid_layout5($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));

        $list_items_markup .= sprintf('<div class="plp-image-wrap">');

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);
        //social share
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-wrap"><i class="fa fa-share-alt" aria-hidden="true"></i>');
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div></div>');
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');

        // Wrap the excerpt content
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"> By <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        $list_items_markup .= sprintf('</div>');

        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }

        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 6
 */

function pl_grid_layout6($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, " / ");
        }

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');

        // Wrap the excerpt content
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"><i class="fas fa-user"></i><span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "><i class="fas fa-calendar-alt"></i> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "><i class="fas fa-comment"></i> %1$s </div>', $number_comment);

        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        $list_items_markup .= sprintf('</div>');

        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');

        // Get the social share
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-wrap">');
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div></div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 7
 */

function pl_grid_layout7($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= sprintf('<div class="plp-category-wrap"><i class="far fa-folder-open"></i>');
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('<div class="plp-image-wrap">');

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate"> <div class="plp-mday"> %1$s </div> %2$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id), get_the_date('M  Y', $post_id));
        }

        // Get the social share
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="plp-' . $attributes["socialopt"] . ' social-share-wrap">');
            $list_items_markup .= sprintf('<div class="social-share-data">');
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div></div>');
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }

        // Wrap the excerpt content
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"> By <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));
        $list_items_markup .= sprintf('<div class="plp-excerpt-wrap">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap plp-clearfix">');

        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "><i class="fas fa-comments"></i> %1$s </div>', $number_comment);

        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 8
 */

function pl_grid_layout8($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the text content
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"> By <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);

        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate"> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $list_items_markup .= sprintf('</div>');

        $list_items_markup .= sprintf('<div class="plp-excerpt-wrap">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Get the bottom wrap
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }

        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 9
 */

function pl_grid_layout9($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));
        $list_items_markup .= sprintf('<div class="plp-image-wrap">');

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-blogpost-text plp-clearfix">');

        // Start the left wrap
        $list_items_markup .= sprintf('<div class="plp-left-wrap">');
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate"> <span>%1$s </span></div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"> <i class="fas fa-user"></i> <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        $list_items_markup .= sprintf('</div>');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        $list_items_markup .= sprintf('</div>'); //left wrap closed
        // Start the right wrap
        $list_items_markup .= sprintf('<div class="plp-right-wrap">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }
        $list_items_markup .= sprintf('<div class="plp-excerpt-wrap">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }
        $list_items_markup .= sprintf('</div>');

        // Close the right wrap
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  Grid template 10
 */

function pl_grid_layout10($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template">', esc_attr($post_thumb_class));
        $list_items_markup .= sprintf('<div class="plp-image-wrap">');

        // Get the post featured image
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate"> <span>%1$s </span> %2$s</div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id), get_the_date('F Y', $post_id));
        }
        $list_items_markup .= sprintf('</div>');

        $list_items_markup .= sprintf('<div class="plp-blogpost-text plp-clearfix">');

        // Start the left wrap
        $list_items_markup .= sprintf('<div class="plp-left-wrap">');
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('</div>'); //left wrap closed
        // Start the right wrap
        $list_items_markup .= sprintf('<div class="plp-right-wrap">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled', 'post-layouts-pro');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"> Posted By <span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        $list_items_markup .= sprintf('</div>');

        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<div class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('</div>');

        // Close the right wrap
        $list_items_markup .= sprintf('</div>');

        // Close the markup for the post
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  List template 1
 */

function pl_list_layout1($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;
        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template"><div class="plp-first-inner-wrap">', esc_attr($post_thumb_class));
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-category-link-wraper">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, ", ");
        }
        $list_items_markup .= sprintf('</div></div>');
        $list_items_markup .= sprintf('<div class="plp-second-inner-wrap" >');

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline"> <div class=" metadatabox">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author">');
            $list_items_markup .= __('By ', 'post-layouts-pro');
            $list_items_markup .= sprintf('<span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate ">');
            $list_items_markup .= __('On', 'post-layouts-pro');
            $list_items_markup .= sprintf(' %1$s</div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }

        // Get post comments
        $comments = get_comments_number($post_id);

        if ($comments > 0) {
            $number_comment = $comments . " Comments";
        } else {
            $number_comment = "No Comments";
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_comment);
        }
        $list_items_markup .= sprintf('</div>');

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-text" ><div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p class="plp-link-wraper"><a class="plp-blogpost-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Close the excerpt content
        $list_items_markup .= sprintf('</div></div><div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('<div class="plp-social-wrap"><div class="social-share-data plp-%1$s">', $attributes['socialopt']);
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
        }
        $list_items_markup .= sprintf('</div></div></div>');
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  List template 2
 */

function pl_list_layout2($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf('<article class="%1$s plp-blog-template"><div class="plp-first-inner-wrap">', esc_attr($post_thumb_class));
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf('<div class="plp-category-link-wraper">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, "  ");
        }
        $list_items_markup .= sprintf(
                '</div></div>'
        );
        $list_items_markup .= sprintf('<div class="plp-second-inner-wrap" >');

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline"> <div class=" metadatabox">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author"><i class="fas fa-pencil-alt"></i><span class="plp-blogpost-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "><i class="fas fa-calendar-alt"></i> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }

        // Get post comments
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_commnet = '<i class="far fa-comment"></i>' . $comments;
        } else {
            $number_commnet = '<i class="far fa-comment"></i> 0';
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf('<div class="post-comments "> %1$s </div>', $number_commnet);
        }
        $list_items_markup .= sprintf('</div>');

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-text" ><div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf('<p class="plp-link-wraper"><a class="plp-blogpost-link plp-famoustext-link" href="%1$s" rel="bookmark">%2$s</a></p>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText']));
        }

        // Close the excerpt content
        $list_items_markup .= sprintf('</div></div><div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '');
        }
        $list_items_markup .= sprintf('<div class="plp-social-wrap"><div class="social-share-data plp-%1$s">', $attributes['socialopt']);
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
        }
        $list_items_markup .= sprintf('</div></div></div>');
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  List template 3
 */

function pl_list_layout3($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf(
                '<article class="%1$s plp-blog-template"><div class="plp-clearfix"><div class="plp-first-inner-wrap">', esc_attr($post_thumb_class)
        );
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // Wrap the text content
        $list_items_markup .= sprintf(
                '<div class="plp-category-link-wraper">'
        );
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, "   ");
        }
        $list_items_markup .= sprintf(
                '</div></div>'
        );
        $list_items_markup .= sprintf(
                '<div class="plp-second-inner-wrap" >'
        );

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-text" ><div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the byline content
        $list_items_markup .= sprintf(
                '<div class="plp-blogpost-byline"> <div class=" metadatabox">'
        );
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf(
                    '<div class="post-author"><i class="fas fa-pencil-alt"></i><span class="plp-blogpost-author">'
            );
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf(
                    '</div>'
            );
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "><i class="fas fa-calendar-alt"></i> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }

        // Get post comments
        $comments = get_comments_number($post_id);

        if ($comments > 0) {
            $number_commnet = '<i class="far fa-comment"></i>' . $comments . "Comments";
        } else {
            $number_commnet = '<i class="far fa-comment"></i> 0 Comment';
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf(
                    '<div class="post-comments "> %1$s </div>', $number_commnet
            );
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the excerpt content
        $list_items_markup .= sprintf(
                '<div class="plp-blogpost-excerpt">'
        );
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }

        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf(
                    '<div class="plp-blogpost-bototm-wrap"><div class="plp-link-wraper"><a class="plp-blogpost-link plp-famoustext-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText'])
            );
        }

        // Close the excerpt content
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        $list_items_markup .= sprintf('<div class="plp-social-wrap"><div class="social-share-data plp-%1$s">', $attributes['socialopt']);
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
        }
        $list_items_markup .= sprintf(
                '</div></div></div></div></div></div>'
        );
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  List template 4
 */

function pl_list_layout4($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf(
                '<article class="%1$s plp-blog-template plp-clearfix">', esc_attr($post_thumb_class)
        );
        $list_items_markup .= sprintf('<div class="plp-first-inner-wrap">');
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        // End of plp-first-inner-wrap
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-second-inner-wrap">');
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-text">');
        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, "   ");
        }

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the byline content
        $list_items_markup .= sprintf(
                '<div class="plp-blogpost-byline">'
        );
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf(
                    '<div class="post-author"><i class="fas fa-pencil-alt"></i><span class="plp-blogpost-author">'
            );
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get the post date
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "><i class="fas fa-calendar-alt"></i> %1$s </div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id));
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }

        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf(
                    '<div class="plp-link-wraper"><a class="plp-blogpost-link plp-famoustext-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText'])
            );
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }

        // Get post comments
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_commnet = $comments . ' Comments';
        } else {
            $number_commnet = ' 0 comment';
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf(
                    '<div class="post-comments "> %1$s </div>', $number_commnet
            );
        }
        $list_items_markup .= sprintf('</div></div></div>');
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/*
 *  List template 5
 */

function pl_list_layout5($attributes) {

    $recent_posts = wp_get_recent_posts(array(
        'numberposts' => !empty($attributes['postsToShow']) ? $attributes['postsToShow'] : '',
        'post_status' => 'publish',
        'order' => !empty($attributes['order']) ? $attributes['order'] : '',
        'orderby' => !empty($attributes['orderBy']) ? $attributes['orderBy'] : '',
        'category' => !empty($attributes['categories']) ? $attributes['categories'] : '',
            ), 'OBJECT');

    $list_items_markup = '';

    foreach ($recent_posts as $post) {

        // Get the post ID
        $post_id = $post->ID;

        if (isset($attributes['displayPostImage']) && $attributes['displayPostImage']) {
            $post_thumb_class = 'has-thumb';
        } else {
            $post_thumb_class = 'no-thumb';
        }

        // Start the markup for the post
        $list_items_markup .= sprintf(
                '<article class="%1$s plp-blog-template plp-clearfix">', esc_attr($post_thumb_class)
        );
        $list_items_markup .= sprintf('<div class="plp-first-inner-wrap">');
        $list_items_markup .= post_layouts_pro_get_featured_image($post_id, $attributes);

        if (isset($attributes['displayPostCategory']) && $attributes['displayPostCategory']) {
            $list_items_markup .= post_layouts_pro_get_category($post_id, "   ");
        }
        $list_items_markup .= sprintf('</div>'); //end of plp-first-inner-wrap
        $list_items_markup .= sprintf('<div class="plp-second-inner-wrap">');
        if (isset($attributes['displayPostDate']) && $attributes['displayPostDate']) {
            $list_items_markup .= sprintf('<div class="mdate "> <span>%1$s </span>%2$s</div>', get_the_date(post_layouts_pro_get_date_format($attributes["dateopt"]), $post_id), get_the_date('M', $post_id));
        }

        // Get the post title
        $title = get_the_title($post_id);
        if (!$title) {
            $title = __('Untitled');
        }
        $list_items_markup .= sprintf('<div class="plp-blogpost-title"><a href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($title));

        // Wrap the byline content
        $list_items_markup .= sprintf('<div class="plp-blogpost-byline">');
        if (isset($attributes['displayPostAuthor']) && $attributes['displayPostAuthor']) {
            $list_items_markup .= sprintf('<div class="post-author">');
            $list_items_markup .= post_layouts_pro_get_author($post_id, $post);
            $list_items_markup .= sprintf('</div>');
        }

        // Get post comments
        $comments = get_comments_number($post_id);
        if ($comments > 0) {
            $number_commnet = $comments . ' Comments';
        } else {
            $number_commnet = ' 0 comment';
        }
        if (isset($attributes['displayPostComments']) && $attributes['displayPostComments']) {
            $list_items_markup .= sprintf(
                    '<div class="post-comments "> %1$s </div>', $number_commnet
            );
        }
        $list_items_markup .= sprintf('</div>');

        // Wrap the excerpt content
        $list_items_markup .= sprintf('<div class="plp-blogpost-excerpt">');
        if (isset($attributes['displayPostExcerpt']) && $attributes['displayPostExcerpt']) {
            $list_items_markup .= post_layouts_pro_get_excerpt($post_id, $post, $attributes);
        }
        if (isset($attributes['displayPostLink']) && $attributes['displayPostLink']) {
            $list_items_markup .= sprintf(
                    '<div class="plp-link-wraper"><a class="plp-blogpost-link plp-famoustext-link" href="%1$s" rel="bookmark">%2$s</a></div>', esc_url(get_permalink($post_id)), esc_html($attributes['readMoreText'])
            );
        }
        $list_items_markup .= sprintf('</div>');
        $list_items_markup .= sprintf('<div class="plp-blogpost-bototm-wrap">');
        if (isset($attributes['displayPostTag']) && $attributes['displayPostTag']) {
            $list_items_markup .= post_layouts_pro_get_tags($post_id, '<i class="fas fa-tags"></i>');
        }
        if (isset($attributes['displayPostSocialshare']) && $attributes['displayPostSocialshare']) {
            $list_items_markup .= sprintf('<div class="social-share-data plp-%1$s">', $attributes['socialopt']);
            $list_items_markup .= post_layouts_pro_get_social_share_icons($post_id);
            $list_items_markup .= sprintf('</div>');
        }


        $list_items_markup .= sprintf('</div></div>');
        $list_items_markup .= "</article>\n";
    }
    return $list_items_markup;
}

/**
 * Registers the `core/latest-posts` block on server.
 */
function post_layouts_pro_register_block_core_latest_posts() {

    // Check if the register function exists
    if (!function_exists('register_block_type')) {
        return;
    }

    register_block_type('post-layouts-pro/plp-blog-templates', array(
        'attributes' => array(
            'block_id' => array(
                'type' => 'string',
                'default' => 'wide',
            ),
            'categories' => array(
                'type' => 'array',
            ),
            'className' => array(
                'type' => 'string',
            ),
            'postsToShow' => array(
                'type' => 'number',
                'default' => 4,
            ),
            'displayPostDate' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostExcerpt' => array(
                'type' => 'boolean',
                'default' => false,
            ),
            'wordsExcerpt' => array(
                'type' => 'number',
                'default' => 25,
            ),
            'displayPostAuthor' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostTag' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostCategory' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostImage' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostLink' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostComments' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'displayPostSocialshare' => array(
                'type' => 'boolean',
                'default' => true,
            ),
            'postLayout' => array(
                'type' => 'string',
                'default' => 'grid',
            ),
            'columns' => array(
                'type' => 'number',
                'default' => 2,
            ),
            'align' => array(
                'type' => 'string',
                'default' => 'center',
            ),
            'width' => array(
                'type' => 'string',
                'default' => 'wide',
            ),
            'order' => array(
                'type' => 'string',
                'default' => 'desc',
            ),
            'orderBy' => array(
                'type' => 'string',
                'default' => 'date',
            ),
            'imageCrop' => array(
                'type' => 'string',
                'default' => 'landscape',
            ),
            'layoutcount' => array(
                'type' => 'number',
                'default' => 1,
            ),
            'layoutcountTwo' => array(
                'type' => 'number',
                'default' => 1,
            ),
            'layoutopt' => array(
                'type' => 'string',
                'default' => 'grid',
            ),
            'dateopt' => array(
                'type' => 'string',
                'default' => 'DD MMM Y',
            ),
            'socialopt' => array(
                'type' => 'string',
                'default' => 'icon',
            ),
            'readMoreText' => array(
                'type' => 'string',
                'default' => 'Read More',
            ),
        ),
        'render_callback' => 'post_layouts_pro_block_render_block_core_latest_posts',
    ));
}

add_action('init', 'post_layouts_pro_register_block_core_latest_posts');

/**
 * Create API fields for additional info
 */
function post_layouts_pro_block_register_rest_fields() {

    // Add landscape featured image source
    register_rest_field(
            'post', 'featured_image_src', array(
        'get_callback' => 'post_layouts_pro_block_get_image_src_landscape',
        'update_callback' => null,
        'schema' => null,
            )
    );

    // Add square featured image source
    register_rest_field(
            'post', 'featured_image_src_square', array(
        'get_callback' => 'post_layouts_pro_block_get_image_src_square',
        'update_callback' => null,
        'schema' => null,
            )
    );

    // Add author info
    register_rest_field(
            'post', 'author_info', array(
        'get_callback' => 'post_layouts_pro_block_get_author_info',
        'update_callback' => null,
        'schema' => null,
            )
    );

    // Add category info
    register_rest_field(
            'post', 'category_info', array(
        'get_callback' => 'post_layouts_pro_block_get_catgeory_info',
        'update_callback' => null,
        'schema' => null,
            )
    );

    // Add tags info
    register_rest_field(
            'post', 'tags_info', array(
        'get_callback' => 'post_layouts_pro_block_get_tags_info',
        'update_callback' => null,
        'schema' => null,
            )
    );

    //add social share info
    register_rest_field(
            'post', 'social_share_info', array(
        'get_callback' => 'post_layouts_pro_get_social_share_info',
        'update_callback' => null,
        'schema' => null,
            )
    );

    //add wordexcerpt
    register_rest_field(
            'post', 'wordExcerpt_info', array(
        'get_callback' => 'post_layouts_pro_block_get_wordExcerpt',
        'update_callback' => null,
        'schema' => null,
            )
    );

    //add comment
    register_rest_field(
            'post', 'comment_info', array(
        'get_callback' => 'post_layouts_pro_get_comment_info',
        'update_callback' => null,
        'schema' => null,
            )
    );
}

add_action('rest_api_init', 'post_layouts_pro_block_register_rest_fields');

/**
 * Get landscape featured image source for the rest field
 */
function post_layouts_pro_block_get_image_src_landscape($object, $field_name, $request) {
    $feat_img_array = wp_get_attachment_image_src($object['featured_media'], 'plp-blogpost-landscape', false);
    
    // Check if $feat_img_array is an array before trying to access its elements
    if (is_array($feat_img_array) && isset($feat_img_array[0])) {
        return $feat_img_array[0];
    } else {
        return ''; // You can return an empty string or some other default value here
    }
}

/**
 * Get square featured image source for the rest field
 */
function post_layouts_pro_block_get_image_src_square($object, $field_name, $request) {
    $feat_img_array = wp_get_attachment_image_src($object['featured_media'], 'plp-blogpost-square', false);
    
    // Check if $feat_img_array is an array before trying to access its elements
    if (is_array($feat_img_array) && isset($feat_img_array[0])) {
        return $feat_img_array[0];
    } else {
        return ''; // You can return an empty string or some other default value here
    }
}

/**
 * Get author info for the rest field
 */
function post_layouts_pro_block_get_author_info($object, $field_name, $request) {
    // Get the author name
    $author_data['display_name'] = get_the_author_meta('display_name', $object['author']);

    // Get the author link
    $author_data['author_link'] = get_author_posts_url($object['author']);

    // Return the author data
    return $author_data;
}

/**
 * Get category info for the rest field
 */
function post_layouts_pro_block_get_catgeory_info($object, $field_name, $request) {
    $object['ID'] = '';
    $categories_list = get_the_category_list(",", "", $object['ID']);
    $cat_class = '';

    $category_info = sprintf('%1$s', $categories_list);
    // Return the category data
    return $category_info;
}

/**
 * Get tags info for the rest field
 */
function post_layouts_pro_block_get_tags_info($object, $field_name, $request) {
    $object['ID'] = '';
    // Get the tag list
    $tags_list = get_the_tag_list("", ", ", "", $object['ID']);
    $tags_info = sprintf('%1$s', $tags_list);
    // Return the tag data
    return $tags_info;
}

/**
 * Get excerpt info for the rest field
 */
function post_layouts_pro_block_get_wordExcerpt($object, $field_name, $request) {
    $object['ID'] = '';
    $excerpt = apply_filters('the_excerpt', get_post_field('post_excerpt', $object['ID'], 'display'));

    if (empty($excerpt)) {
        $excerpt = apply_filters('the_excerpt', get_the_content($object['ID']));
    }

    if (!$excerpt) {
        $excerpt = null;
    }
    $list_items_markup = wp_kses_post($excerpt);

    return $list_items_markup;
}

/**
 * Get social share info for the rest field
 */
function post_layouts_pro_get_social_share_info($object, $field_name, $request) {
    $object['ID'] = '';
    $social_share_info = sprintf('<a data-share="facebook" href="https://www.facebook.com/sharer.php?u=%1$s" class="plp-facebook-share social-share-default plp-social-share" target="_blank"><i class="fab fa-facebook-f" aria-hidden="true"></i></a>', get_the_permalink($object['ID']));
    $social_share_info .= sprintf('<a data-share="twitter" href="https://twitter.com/share?url=%1$s" class="plp-twitter-share social-share-default plp-social-share" target="_blank"><i class="fab fa-twitter" aria-hidden="true"></i></a>', get_the_permalink($object['ID']));
    $social_share_info .= sprintf('<a data-share="linkedin" href="https://www.linkedin.com/shareArticle?url=%1$s" class="plp-linkedin-share social-share-default plp-social-share" target="_blank"><i class="fab fa-linkedin-in" aria-hidden="true"></i></a>', get_the_permalink($object['ID']));
    return $social_share_info;
}

/**
 * Get comment info for the rest field
 */
function post_layouts_pro_get_comment_info($object, $field_name, $request) {
    $object['ID'] = '';
    $comments = get_comments_number($object['ID']);
    if ($comments > 0) {
        return $comments . " Comments";
    } else {
        return "No Comment";
    }
}
